<?php
/*
Plugin Name: Delivery Date and Time
Description: Im Checkout wird die Möglichkeit zur Einstellung eines gewünschten Lieferzeitraums gegeben.
Version: 1.0
Author: Webdesign OWL
*/

// WD OWL 2023

add_filter( 'wc_product_sku_enabled', '__return_false' );

add_filter( 'woocommerce_checkout_fields' , 'disable_billing_country_editing' );
function disable_billing_country_editing( $fields ) {
    // Set the billing country to Germany
    $fields['billing']['billing_country']['default'] = 'DE';

    // Disable the billing country field
    $fields['billing']['billing_country']['custom_attributes'] = array( 'disabled' => 'disabled' );

    return $fields;
}
// 2 Tage Voraus
add_filter( 'woocommerce_checkout_fields', 'limit_delivery_date_selection' );
function limit_delivery_date_selection( $fields ) {
	 
    // Heutiger Tag
    $current_date = date( 'Y-m-d' );
    
    // Berechnung Min und Max
    $min_delivery_date = date( 'Y-m-d', strtotime( '+2 day', strtotime( $current_date ) ) );
    $max_delivery_date = date( 'Y-m-d', strtotime( '+7 day', strtotime( $current_date ) ) );
    
    // Optionen
    $delivery_date_options = array();
    $delivery_date_options[''] = 'Bitte wählen...';
    
    // Options array
    for ( $i = strtotime( $min_delivery_date ); $i <= strtotime( $max_delivery_date ); $i = strtotime( '+1 day', $i ) ) {
        $delivery_date = date( 'Y-m-d', $i );
        $delivery_date_options[ $delivery_date ] = date( 'l, j. F Y', $i );
    }
    
    // Min als Standard
    $default_delivery_date = $min_delivery_date;
    
    // Lieferdatum Felder
    $fields['billing']['billing_delivery_date'] = array(
        'type'          => 'select',
        'label'         => 'Lieferdatum',
        'options'       => $delivery_date_options,
        'default'       => $default_delivery_date,
        'required'      => true,
    );
    
    return $fields;
}

// Min Time Slot
add_filter( 'woocommerce_delivery_slots_min_date', 'set_delivery_slots_min_date' );
function set_delivery_slots_min_date( $min_date ) {
    // Heutiger Tag
    $current_date = date( 'Y-m-d' );
    
    // Berechnung Min
    $min_delivery_date = date( 'Y-m-d', strtotime( '+2 day', strtotime( $current_date ) ) );
    
    // Ausgabe Min
    return $min_delivery_date;
}

/**
 * Felder im Checkout
 */
add_filter('woocommerce_checkout_fields', 'add_delivery_fields');
function add_delivery_fields($fields) {
    $delivery_date_options = array();
    $default_delivery_date = date_i18n('Y-m-d', strtotime('+2 days'));

    // Lieferzeitslots dem Checkout hinzufügen
    $time_slots = array(
        '11:30 - 12:00' => '11:30 - 12:00',
        '12:00 - 12:30' => '12:00 - 12:30',
        '12:30 - 13:00' => '12:30 - 13:00',
        '13:00 - 13:30' => '13:00 - 13:30',
        '13:30 - 14:00' => '13:30 - 14:00',
        '14:00 - 14:30' => '14:00 - 14:30',
        '14:30 - 15:00' => '14:30 - 15:00',
        '15:00 - 15:30' => '15:00 - 15:30',
        '15:30 - 16:00' => '15:30 - 16:00',
        '16:00 - 16:30' => '16:00 - 16:30',
        '16:30 - 17:00' => '16:30 - 17:00',
        '17:00 - 17:30' => '17:00 - 17:30',
        '17:30 - 18:00' => '17:30 - 18:00',
        '18:00 - 18:30' => '18:00 - 18:30',
        '18:30 - 19:00' => '18:30 - 19:00',
    );

    // Lieferfelder dem Checkout hinzufügen
    $fields['billing']['billing_delivery_time'] = array(
        'type' => 'select',
        'label' => __('Lieferzeit'),
        'required' => true,
        'class' => array('form-row-wide', 'update_totals_on_change'),
        'custom_attributes' => array(
            'autocomplete' => 'off',
        ),
        'options' => $time_slots,
        'default' => '11:30 - 12:00',
    );

    // Revert date field to calendar
    $fields['billing']['billing_delivery_date'] = array(
        'type' => 'date',
        'label' => __('Lieferdatum (Bitte wählen Sie ein Lieferdatum aus. Beachten Sie, dass wir Bestellungen frühestens in zwei Tagen ausliefern. Vielen Dank!)'),
        'required' => true,
        'class' => array('form-row-wide', 'update_totals_on_change'),
        'custom_attributes' => array(
            'autocomplete' => 'off',
            'min' => date_i18n('Y-m-d', strtotime('+2 days')),
        ),
        'options' => $delivery_date_options,
        'default' => $default_delivery_date,
    );

    return $fields;
}



add_action( 'woocommerce_checkout_process', 'validate_delivery_date' );

function validate_delivery_date() {
    $delivery_date = isset( $_POST['billing_delivery_date'] ) ? sanitize_text_field( $_POST['billing_delivery_date'] ) : '';
    $current_date = date_i18n( 'Y-m-d' );
    $min_delivery_date = date_i18n( 'Y-m-d', strtotime( "+2 days" ) );

    if ( $delivery_date < $min_delivery_date ) {
        wc_add_notice( __( 'Bitte wählen Sie ein Lieferdatum aus. Beachten Sie, dass wir Bestellungen frühestens in zwei Tagen ausliefern. Vielen Dank!', 'woocommerce' ), 'error' );
    }
}

add_action( 'woocommerce_after_checkout_form', 'add_delivery_date_js' );
function add_delivery_date_js() {
    ?>
    <script>
        jQuery(function($){
            var today = new Date();
            var minDate = new Date(today.getTime() + 48 * 60 * 60 * 1000).toISOString().split('T')[0];
            $('input#billing_delivery_date').attr('min', minDate);
        });
    </script>
    <?php
}

add_action( 'woocommerce_after_checkout_form', 'add_delivery_date_picker' );

function add_delivery_date_picker() {
    ?>
    <script>
    jQuery(document).ready(function($){

        // 2 Tage im Voraus
        var now = new Date();
        var minDate = new Date(now.getFullYear(), now.getMonth(), now.getDate()+5);

        // Deaktiviert die Daten vor diesem Tag
        function disableDates(date) {
            return date < minDate;
        }

        // Initialisierung des Datepickers
        $( '#billing_delivery_date' ).datepicker({
            minDate: minDate,
            beforeShowDay: disableDates,
            dateFormat: 'yy-mm-dd'
        });

        // Ändert das Feld des Lieferzeitraums bei einer anderen Auswahl
        $( 'form.checkout' ).on( 'change', 'input[name^="billing_delivery_time"]', function() {
            $( '#billing_delivery_date' ).val( '' );
        });

    });
    </script>
    <?php
}




// Einhooken
add_filter( 'woocommerce_email_order_meta_fields', 'zafer_add_email_order_meta', 10, 3 );

function zafer_add_email_order_meta( $fields, $sent_to_admin, $order ) {
    $liefertag = $order->get_meta( '_billing_delivery_date' );
    $lieferzeit = $order->get_meta( '_billing_delivery_time' );
	$liefertag = date( 'd.m.Y', strtotime( $liefertag ) );

    if ( $liefertag ) {
        $fields['billing_delivery_date'] = array(
            'label' => __( 'Liefertag' ),
            'value' => $liefertag,
			
        );
    }

    if ( $lieferzeit ) {
        $fields['billing_delivery_time'] = array(
            'label' => __( 'Lieferzeit' ),
            'value' => $lieferzeit,
        );
    }

    return $fields;
}

add_filter( 'manage_edit-shop_order_columns', 'lieferspalten' );
function lieferspalten( $columns ) {
    $columns['liefertag'] = __( 'Liefertag', 'text-domain' );
    $columns['lieferzeit'] = __( 'Lieferzeit', 'text-domain' );
    return $columns;
}

add_action( 'manage_shop_order_posts_custom_column' , 'lieferspalteninhalt' );
function lieferspalteninhalt( $column ) {
    global $post;
    $order = wc_get_order( $post->ID );
    if ( $column == 'liefertag' ) {
        echo $order->get_meta( '_billing_delivery_date' );
    } elseif ( $column == 'lieferzeit' ) {
        echo $order->get_meta( '_billing_delivery_time' );
    }
}

// Hinzufügen von Feldern für den Lieferdatum und die Lieferzeit in der Bestellungs-Metabox
add_action( 'woocommerce_admin_order_data_after_billing_address', 'lieferdaten_dashboard', 10, 1 );
function lieferdaten_dashboard($order){
    	$delivery_date = get_post_meta( $order->get_id(), '_billing_delivery_date', true );
		$liefertagde = date( 'd.m.Y', strtotime( $delivery_date ) );
	echo '<p><strong>Liefertag:</strong> ' . $liefertagde . '</p>';
    echo '<p><strong>'.__('Lieferzeit').':</strong> ' . get_post_meta( $order->get_id(), '_billing_delivery_time', true ) . ' Uhr</p>';

}


// Display delivery date and time on "Thank you" page and "My Account" order view
add_action( 'woocommerce_thankyou', 'display_delivery_date_time_thankyou', 10, 1 );
add_action( 'woocommerce_view_order', 'display_delivery_date_time_thankyou', 10, 1 );

function display_delivery_date_time_thankyou( $order_id ) {
    $order = wc_get_order( $order_id );
    $delivery_date = $order->get_meta( '_billing_delivery_date' );
    $delivery_time = $order->get_meta( '_billing_delivery_time' );

    if ( $delivery_date ) {
        $formatted_delivery_date = date( 'd.m.Y', strtotime( $delivery_date ) );
        echo '<p><strong>Liefertag:</strong> ' . $formatted_delivery_date . '</p>';
    }

    if ( $delivery_time ) {
        echo '<p><strong>Lieferzeit:</strong> ' . esc_html( $delivery_time ) . '</p>';
    }
}
